@@ -233,7 +233,9 @@
   e)
 (with-test (:name :macroexpand-setf-instance-ref.1)
   (assert (equal-mod-gensyms
-           (macroexpand-1 '(setf (foo-a x) 3))
+           (macroexpand-1 '(setf (foo-a x) 3)
+                          (locally (declare (optimize (sb-c::store-xref-data 0)))
+                            (capture-env)))
            `(let ((#1=instance (the foo x))
                   (#2=val (sb-kernel:the* (fixnum :context (sb-kernel::struct-context foo . a)) 3)))
               (sb-kernel:%instance-set #1# #.sb-vm:instance-data-start #2#)
@@ -322,9 +324,7 @@
                (if (sb-int:memq x '(a b c d e f g h i j k l m n o p)) 1 2))))
          (code (sb-kernel:fun-code-header f))
          (constant
-           (sb-kernel:code-header-ref
-            code
-            (+ sb-vm:code-constants-offset sb-vm:code-slots-per-simple-fun))))
+          (sb-kernel:code-header-ref code sb-vm:code-constants-offset)))
     ;; should have a vector of symbols, not references to each symbol
     (assert (vectorp constant))
     (assert (eql (funcall f 'j) 1))
@@ -336,13 +336,9 @@
                    -1))))
          (code (sb-kernel:fun-code-header f))
          (constant1
-           (sb-kernel:code-header-ref
-            code
-            (+ sb-vm:code-constants-offset sb-vm:code-slots-per-simple-fun)))
+           (sb-kernel:code-header-ref code sb-vm:code-constants-offset))
          (constant2
-           (sb-kernel:code-header-ref
-            code
-            (+ (1+ sb-vm:code-constants-offset) sb-vm:code-slots-per-simple-fun))))
+           (sb-kernel:code-header-ref code (1+ sb-vm:code-constants-offset))))
     ;; These accesses are safe because if the transform happened,
     ;; there should be 2 constants, and if it didn't, then at least 2 constants.
     (assert (and (vectorp constant1) (vectorp constant2)))
